package app.ara.activities;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.TextView;

import app.ara.utils.AndroidResources;
import app.ara.utils.FontChangeCrawler;
import app.ara.utils.error.ErrorHandler;
import app.ara.utils.game.Resource;
import app.ara.utils.files.FileManager;
import uk.co.senab.photoview.PhotoViewAttacher;

/**
 * An example full-screen activity that shows and hides the system UI (i.e.
 * status bar and navigation/system bar) with user interaction.
 */
public class ImageViewerActivity extends Activity implements IViewerActivity{


    private Resource mResource;
    private ImageView mImageView;
    private Button mButton;
    private PhotoViewAttacher mAttacher;
    private boolean mIsMap=false;


    public static final int CONTENT_NULL=0;
    public static final int CONTENT_MAP=1;
    public static final int CONTENT_INFO=2;
    public static final int CONTENT_IMAGE=3;
    public static final int CONTENT_3D=4;
    protected int mContent=CONTENT_NULL;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_viewer);

        try {
            mImageView = (ImageView) findViewById(R.id.imageView);
            mButton = (Button) findViewById(R.id.info);
            if (getIntent().hasExtra("resource")) {
                mResource = (Resource) getIntent().getSerializableExtra("resource");
                if (mResource != null) setTitle(mResource.getTitle());
            }

            final TextView title = (TextView) findViewById(R.id.title);
            title.setVisibility(View.VISIBLE);

            if (mResource != null && !getIntent().hasExtra("information") && !getIntent().hasExtra("map")) {
                title.setText(mResource.getTitle());
                if (mResource.isImage()) {
                    mContent = CONTENT_IMAGE;
                    Bitmap bmp = null;
                    try {
                        bmp = FileManager.openImage(this, mResource.getName());
                    } catch (Exception e) {
                        e.printStackTrace();
                    }

                    mImageView.setImageBitmap(bmp);
                    mAttacher = new PhotoViewAttacher(mImageView);
                    mAttacher.setMaximumScale(20);

                }

            } else if (getIntent().hasExtra("map")) {
                mContent = CONTENT_MAP;
                Bitmap bmp = null;
                try {
                    bmp = FileManager.openImage(this, "map");
                } catch (Exception e) {
                    e.printStackTrace();
                }
                title.setVisibility(View.GONE);
                mImageView.setImageBitmap(bmp);
                mAttacher = new PhotoViewAttacher(mImageView);
                mAttacher.setMaximumScale(20);
                mButton.setVisibility(View.GONE);
                mIsMap=true;
            } else {
                title.setText("Erreur");
            }
            FontChangeCrawler.setFont(this);
        }catch(Exception e)
        {
            e.printStackTrace();
            ErrorHandler.addError(this, e);
        }

    }

    public void onClickInfo(View v)
    {
        try {
            Intent intent = AndroidResources.getInfoIntent(this, mResource);
            startActivity(intent);
        }catch(Exception e)
        {
            e.printStackTrace();
            ErrorHandler.addError(this, e);
        }
    }


    public void onClick(View v)
    {
        try {
            if (mContent == CONTENT_IMAGE) {

                final TextView title = (TextView) findViewById(R.id.title);
                if (title.getVisibility() == View.VISIBLE) {
                    title.setVisibility(View.GONE);
                    mButton.setVisibility(View.GONE);
                } else {

                    title.setVisibility(View.VISIBLE);
                    mButton.setVisibility(View.VISIBLE);
                }
            }
        }catch(Exception e)
        {
            e.printStackTrace();
            ErrorHandler.addError(this, e);
        }
    }


    public void onBackPressed() {
        TextView title = (TextView) findViewById(R.id.title);
        if(!mIsMap && title.getVisibility() != View.VISIBLE)
        {
            onClick(null);
        }else super.onBackPressed();
    }
}
